==> download_v2.3.661.zip: download/include/download_managegroup.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains everything to manage groups
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-12-07 FPG created the script
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


setSession("GLAERRORMESSAGE", "");
$defaultErrorMsg=$lang['contactSysadmin'];

if ($_POST['TYPE'] == "NEW") {
    $sQuery = "INSERT INTO `GROUP` (GNAME) VALUES (?)";
} else {
    $sQuery = "UPDATE `GROUP` SET GNAME = ? WHERE GID = ?";
}
debugIntofile("sQuery=".$sQuery);

$statement = mysqli_prepare($databaseConnection, $sQuery);
setSession("GLASQLEXIT", logSQLError($sQuery));

if (withoutSQLError()) {
    if ($_POST['TYPE'] == "NEW") {
        if (!mysqli_stmt_bind_param($statement, "s", $_POST['GROUP'])) {
            setSession("GLASQLEXIT", logSQLErrorManual("Error binding input params with sql-statement: ".$sQuery));
        } else {
            mysqli_stmt_execute($statement);
        }
    } else {
        if (!mysqli_stmt_bind_param($statement, "si", $_POST['GROUP'], $_POST['GID'])) {
            setSession("GLASQLEXIT", logSQLErrorManual("Error binding input params with sql-statement: ".$sQuery));
        } else {
            mysqli_stmt_execute($statement);
        }
    }
}
closePreparedStatement($statement);
header ("Location: index.php?mode=groups");
?>

==> download_v3.0.681.zip: download/include/download_managegroup.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains everything to manage groups
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-12-07 FPG created the script
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


setSession("GLAERRORMESSAGE", "");
$defaultErrorMsg=$lang['contactSysadmin'];

if ($_POST['TYPE'] == "NEW") {
    $sQuery = "INSERT INTO `".getDBTablePrefix()."GROUP` (GNAME) VALUES (?)";
} else {
    $sQuery = "UPDATE `".getDBTablePrefix()."GROUP` SET GNAME = ? WHERE GID = ?";
}
debugIntofile("sQuery=".$sQuery);

$statement = mysqli_prepare($databaseConnection, $sQuery);
setSession("GLASQLEXIT", logSQLError($sQuery));

if (withoutSQLError()) {
    if ($_POST['TYPE'] == "NEW") {
        if (!mysqli_stmt_bind_param($statement, "s", $_POST['GROUP'])) {
            setSession("GLASQLEXIT", logSQLErrorManual("Error binding input params with sql-statement: ".$sQuery));
        } else {
            mysqli_stmt_execute($statement);
        }
    } else {
        if (!mysqli_stmt_bind_param($statement, "si", $_POST['GROUP'], $_POST['GID'])) {
            setSession("GLASQLEXIT", logSQLErrorManual("Error binding input params with sql-statement: ".$sQuery));
        } else {
            mysqli_stmt_execute($statement);
        }
    }
}
closePreparedStatement($statement);
header ("Location: index.php?mode=groups");
?>
